@@ -767,35 +767,41 @@ vcov.fixest = function(object, vcov = NULL, se = NULL, cluster, ssc = NULL, attr
 
     if(anyNA(bread)){
 
+        IS_NA_VCOV = FALSE
+
         if(!forceCovariance){
-            last_warn = getOption("fixest_last_warning")
-            if(is.null(last_warn) || (proc.time() - last_warn)[3] > 1){
-                warning("Standard errors are NA because of likely presence of collinearity.", call. = FALSE)
-            }
-
-            attr(bread, "type") = "NA (not-available)"
-
-            return(bread)
+            IS_NA_VCOV = TRUE
         } else {
             info_inv = cpp_cholesky(object$hessian)
             if(!is.null(info_inv$all_removed)){
                 # Means all variables are collinear! => can happen when using FEs
-                stop("All variables have virtually no effect on the dependent variable. Covariance is not defined.")
+                IS_NA_VCOV = TRUE
             }
-
-            VCOV_raw_forced = info_inv$XtX_inv
-            if(any(info_inv$id_excl)){
-                n_collin = sum(info_inv$all_removed)
-                message("NOTE: ", n_letter(n_collin), " variable", plural(n_collin, "s.has"), " been found to be singular.")
-
-                VCOV_raw_forced = cpp_mat_reconstruct(VCOV_raw_forced, info_inv$id_excl)
-                VCOV_raw_forced[, info_inv$id_excl] = NA
-                VCOV_raw_forced[info_inv$id_excl, ] = NA
-            }
-
-            bread = VCOV_raw_forced
         }
 
+        if(IS_NA_VCOV){
+            attr(bread, "type") = "NA (not-available)"
+
+            if(is_attr){
+                attr(bread, "dof.K") = object$nparams
+                attr(bread, "df.t") = NA
+            }
+
+            return(bread)
+        }
+
+        VCOV_raw_forced = info_inv$XtX_inv
+        if(any(info_inv$id_excl)){
+            n_collin = sum(info_inv$all_removed)
+            message("NOTE: ", n_letter(n_collin), " variable", plural(n_collin, "s.has"), " been found to be singular.")
+
+            VCOV_raw_forced = cpp_mat_reconstruct(VCOV_raw_forced, info_inv$id_excl)
+            VCOV_raw_forced[, info_inv$id_excl] = NA
+            VCOV_raw_forced[info_inv$id_excl, ] = NA
+        }
+
+        bread = VCOV_raw_forced
+
     }
 
     ####
@@ -1321,7 +1327,15 @@ vcov_cluster = function(x, cluster = NULL, ssc = NULL){
 #'
 #' @param unit A character scalar or a one sided formula giving the name of the variable representing the units of the panel.
 #' @param time A character scalar or a one sided formula giving the name of the variable representing the time.
-#' @param lag An integer scalar, default is \code{NULL}. If \code{NULL}, then the default lag is equal to \code{n_t^0.25} with \code{n_t} the number of time periods.
+#' @param lag An integer scalar, default is \code{NULL}. If \code{NULL}, then the default lag is equal to \code{n_t^0.25} with \code{n_t} the number of time periods (as of Newey and West 1987) for panel Newey-West and Driscoll-Kraay. The default for the time series Newey-West is computed via \code{\link[sandwich:NeweyWest]{bwNeweyWest}} which implements the Newey and West 1994 method.
+#'
+#' @section Lag selection:
+#'
+#' The default lag selection depends on whether the VCOV applies to a panel or a time series.
+#'
+#' For panels, i.e. panel Newey-West or Driscoll-Kraay VCOV, the default lag is \code{n_t^0.25} with \code{n_t} the number of time periods. This is based on Newey and West 1987.
+#'
+#' For time series Newey-West, the default lag is found thanks to the \code{\link[sandwich:NeweyWest]{bwNeweyWest}} function from the \code{sandwich} package. It is based on Newey and West 1994.
 #'
 #'
 #' @references
@@ -1850,19 +1864,24 @@ vcov_newey_west_internal = function(bread, scores, vars, ssc, sandwich, nthreads
 
     n_time = max(time)
 
-    # Lag: simple rule of thumb
-    if(missnull(lag)){
-        lag = floor(n_time^(1/4))
+    # The bartlett weights
+    set_weights = function(lag){
+        res = seq(1, 0, by = -(1/(lag + 1)))
+        # we must halve the first weight (we'll add the transpose internally)
+        res[1] = 0.5
+        res
     }
 
-    w = seq(1, 0, by = -(1/(lag + 1)))
-    # we halve the first weight (since we add the transpose in the internal code)
-    w[1] = 0.5
-
-    # We check the consistency
     is_panel = !is.null(unit)
     if(is_panel){
 
+        # Lag: simple rule of thumb
+        if(missnull(lag)){
+            lag = floor(n_time^(1/4))
+        }
+
+        w = set_weights(lag)
+
         my_order = order(time, unit)
         time_ro = time[my_order]
         unit_ro = unit[my_order]
@@ -1890,6 +1909,25 @@ vcov_newey_west_internal = function(bread, scores, vars, ssc, sandwich, nthreads
         time_ro = time[my_order]
         scores_ro = scores[my_order, , drop = FALSE]
 
+        # Lag: the default relies on bwNeweyWest
+        if(missnull(lag)){
+
+            # Later => feed in directly the matrix when the new version of sandwich is ready
+
+            # we drop the intercept (except if there's only the intercept)
+            is_intercept = (colnames(scores_ro) == "(Intercept)") & (ncol(scores_ro) > 1)
+            if(any(is_intercept)){
+                x = structure(list(scores = scores_ro[, !is_intercept, drop = FALSE]), class = "fixest")
+            } else {
+                x = structure(list(scores = scores_ro), class = "fixest")
+            }
+
+            lag = sandwich::bwNeweyWest(x, weights = 1)
+            lag = floor(lag)
+        }
+
+        w = set_weights(lag)
+
         meat = cpp_newey_west(scores_ro, w, nthreads)
     }
 
@@ -2425,8 +2463,6 @@ setFixest_ssc = function(ssc.type = ssc()){
 }
 
 #' @rdname ssc
-"getFixest_ssc"
-
 getFixest_ssc = function(){
 
     ssc = getOption("fixest_ssc")
