@@ -6,7 +6,7 @@
 
 
 
-error_catcher = function(expr) tryCatch(expr, error = function(e) structure(conditionMessage(e), class = "try-error"))
+
 
 test = function(x, y, type = "=", tol = 1e-6){
     mc = match.call()
@@ -20,12 +20,12 @@ test = function(x, y, type = "=", tol = 1e-6){
 
     if(type == "=" && is.numeric(x)){
         type = "~"
-        tol = 1e-12
+        if(missing(tol)) tol = 1e-12
     }
 
     if(type == "err"){
         # we expect an error
-        m = error_catcher(x)
+        m = tryCatch(x, error = function(e) structure(conditionMessage(e), class = "try-error"))
         if(!"try-error" %in% class(m)){
             stop("Expected an error that did not occur.")
         } else if(IS_Y && !grepl(tolower(y), tolower(m), fixed = TRUE)){
@@ -217,6 +217,75 @@ non_ascii = function(folder = "R"){
         if(id < n) cat("\n ---------- \n\n")
     }
 }
+
+
+# To circumvent an Rstudio/Google Drive bug preventing
+# the source files to remain open when closing/opening the project
+open_all = function(){
+
+    # Opening R files
+
+    R_not_open = c("R/alias_generator.R", "R/RcppExports.R", "R/Deprecated_funs.R", "R/index",
+                   "R/etable_aliases.R", "R/ML_Families.R", "R/VCOV_aliases.R", "R/xaxis.R")
+
+    R_files = list.files("R/", full.names = TRUE)
+
+    for(f in R_files){
+        if(f %in% R_not_open) next
+        eval(str2lang(dsb("rstudioapi::navigateToFile('.[f]', moveCursor = FALSE)")))
+    }
+
+    # Opening extra files
+
+    extra_files = c("../PROBLEMS.R", "../Problems.Rmd", "../Development.R",
+                    "../social.rmd", "NEWS.md", "DESCRIPTION", "tests/fixest_tests.R",
+                    list.files("vignettes/", pattern = "Rmd$", full.names = TRUE),
+                    "../todo.txt")
+
+    for(f in extra_files){
+        eval(str2lang(dsb("rstudioapi::navigateToFile('.[f]', moveCursor = FALSE)")))
+    }
+
+
+}
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 
 
