@@ -1,18 +1,8 @@
 ## ----setup, include=FALSE-----------------------------------------------------
 knitr::opts_chunk$set(echo = TRUE, comment = "#>")
 
-if(requireNamespace("pander", quietly = TRUE)) library(pander)
-
-require_pander_ON = function(){
-  if(!requireNamespace("pander", quietly = TRUE)){
-    knitr::opts_chunk$set(eval = FALSE)
-    cat("Evaluation of the next chunks requires 'pander', which is not present.")
-  }
-}
-
-require_pander_OFF = function(){
-  knitr::opts_chunk$set(eval = TRUE)
-}
+is_pander = requireNamespace("pander", quietly = TRUE)
+if(is_pander) library(pander)
 
 library(fixest)
 setFixest_notes(FALSE)
@@ -38,25 +28,19 @@ etable(est)
 etable(est, style.df = style.df(depvar.title = "", fixef.title = "", 
                                  fixef.suffix = " fixed effect", yesNo = "yes"))
 
-## ---- echo = FALSE------------------------------------------------------------
-require_pander_ON()
-
-## -----------------------------------------------------------------------------
+## ---- eval = is_pander--------------------------------------------------------
 library(pander)
 
 etable(est, postprocess.df = pandoc.table.return, style = "rmarkdown")
 
-## -----------------------------------------------------------------------------
+## ---- eval = is_pander--------------------------------------------------------
 my_style = style.df(depvar.title = "", fixef.title = "", 
                     fixef.suffix = " fixed effect", yesNo = "yes")
 setFixest_etable(style.df = my_style, postprocess.df = pandoc.table.return)
 
-## -----------------------------------------------------------------------------
+## ---- eval = is_pand, eval = is_pander----------------------------------------
 etable(est[rhs = 2], style = "rmarkdown", caption = "New default values")
 
-## ---- echo = FALSE------------------------------------------------------------
-require_pander_OFF()
-
 ## -----------------------------------------------------------------------------
 est_slopes = feols(Ozone ~ Solar.R + Wind | Day + Month[Temp], airquality)
 
@@ -102,16 +86,16 @@ etable(est, est_slopes, heavy = "0.14em", tex = TRUE)
 
 ## -----------------------------------------------------------------------------
 fitstat_register(type = "p_s", alias = "pvalue (standard)",
-                 fun = function(x) pvalue(x, se = "s")["Solar.R"])
+                 fun = function(x) pvalue(x, vcov = "iid")["Solar.R"])
 
 fitstat_register(type = "p_h", alias = "pvalue (Heterosk.)",
-                 fun = function(x) pvalue(x, se = "h")["Solar.R"])
+                 fun = function(x) pvalue(x, vcov = "hetero")["Solar.R"])
 
 fitstat_register(type = "p_day", alias = "pvalue (Day)",
-                 fun = function(x) pvalue(x, cluster = "Day")["Solar.R"])
+                 fun = function(x) pvalue(x, vcov = ~Day)["Solar.R"])
 
 fitstat_register(type = "p_month", alias = "pvalue (Month)",
-                 fun = function(x) pvalue(x, cluster = "Month")["Solar.R"])
+                 fun = function(x) pvalue(x, vcov = ~Month)["Solar.R"])
 
 # We first reset the default values set in the previous sections
 setFixest_etable(reset = TRUE)
