@@ -110,18 +110,22 @@ int pending_interrupt() {
 // Later I may use the number of observations
 // I don't at the moment because everything is strongly checked beforehand
 class sVec{
-    bool is_int = false;
     double *p_dble = nullptr;
     int *p_int = nullptr;
 
 public:
     // several constructors
+
+    // is_int public member
+    bool is_int = false;
+
     sVec(){};
     sVec(SEXP);
-    sVec(double *p_x): is_int(false), p_dble(p_x){};
-    sVec(int *p_x): is_int(true), p_int(p_x){};
+    sVec(double *p_x): p_dble(p_x), is_int(false){};
+    sVec(int *p_x): p_int(p_x), is_int(true){};
     sVec(std::nullptr_t){};
 
+
     double operator[](int i){
         if(is_int) return static_cast<double>(p_int[i]);
         return p_dble[i];
@@ -1796,7 +1800,7 @@ List cpp_demean(SEXP y, SEXP X_raw, SEXP r_weights, int iterMax, double diffMax,
                    SEXP fe_id_list, SEXP table_id_I, SEXP slope_flag_Q, SEXP slope_vars_list,
                    SEXP r_init, int nthreads, bool save_fixef = false){
     // main fun that calls demean_single
-    // preformat all the information needed on the clusters
+    // preformats all the information needed on the fixed-effects
     // y: the dependent variable
     // X_raw: the matrix of the explanatory variables -- can be "empty"
 
@@ -2087,7 +2091,12 @@ List cpp_which_na_inf(SEXP x, int nthreads){
     for(int t=0 ; t<nthreads ; ++t){
         for(int k=0 ; k<K ; ++k){
             for(int i=bounds[t]; i<bounds[t + 1] && !anyNAInf ; ++i){
-                if(std::isnan(mat(i, k)) || std::isinf(mat(i, k))){
+
+                if(mat[k].is_int){
+                    if(mat(i, k) == -2147483648.0){
+                        anyNAInf = true;
+                    }
+                } else if(std::isnan(mat(i, k)) || std::isinf(mat(i, k))){
                     anyNAInf = true;
                 }
             }
@@ -2103,7 +2112,13 @@ List cpp_which_na_inf(SEXP x, int nthreads){
             double x_tmp = 0;
             for(int k=0 ; k<K ; ++k){
                 x_tmp = mat(i, k);
-                if(std::isnan(x_tmp)){
+                if(mat[k].is_int){
+                    if(mat(i, k) == -2147483648.0){
+                        is_na_inf[i] = true;
+                        any_na = true;
+                        break;
+                    }
+                } else if(std::isnan(x_tmp)){
                     is_na_inf[i] = true;
                     any_na = true;
                     break;
